{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_communities/base.html" %}

{%- set title = _("New community") -%}

{%- block javascript %}
{{ super() }}
{{ webpack['invenio-communities-new.js'] }}
{%- endblock javascript %}


{%- block page_body %}
<div
    id="app"
    data-form-config='{{ form_config | tojson }}'
    data-custom-fields='{{ custom_fields | tojson }}'
  >
</div>
{%- endblock page_body %}
